*******
Authors
*******

Contributors to Mopidy in the order of appearance:

.. include:: ../AUTHORS


Showing your appreciation
=========================

If you already enjoy Mopidy, or don't enjoy it and want to help us making
Mopidy better, the best way to do so is to contribute back to the community.
You can contribute code, documentation, tests, bug reports, or help other
users, spreading the word, etc.
